==> freecad_0.16.6712+dfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Plot/resources/translations/Plot_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Plotbewerkingsgereedschappen</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Configureer assen</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>De parameters voor de assen instellen</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="110"/>
      <source>Show/Hide grid</source>
      <translation>Raster weergeven/verbergen</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="113"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Weergeven/verbergen raster geselecteerde plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="154"/>
      <source>Set labels</source>
      <translation>Benamingen instellen</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="157"/>
      <source>Set title and axes labels</source>
      <translation>Hoofding en asbenamingen instellen</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="137"/>
      <source>Show/Hide legend</source>
      <translation>Legenda weergeven/verbergen</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="140"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Weergeven/verbergen legende geselecteerde plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="171"/>
      <source>Set positions and sizes</source>
      <translation>Posities en groottes instellen</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="174"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Plaatsing en grootte van benamingen en legende instellen</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Plot opslaan</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>De plot als een imagebestand opslaan</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Configureer series</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Tekenstijl en benaming van series bepalen</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Configureer assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Active axes</source>
      <translation>Actieve assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Apply to all axes</source>
      <translation>Toepassen op alle assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="225"/>
      <source>Dimensions</source>
      <translation>Dimensies</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="230"/>
      <source>X axis position</source>
      <translation>Positie X-as</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="235"/>
      <source>Y axis position</source>
      <translation>Positie Y-as</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="205"/>
      <source>Scales</source>
      <translation>Schalen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="210"/>
      <source>X auto</source>
      <translation>X auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="215"/>
      <source>Y auto</source>
      <translation>Y auto</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="240"/>
      <source>Index of the active axes</source>
      <translation>Index van de actieve assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="245"/>
      <source>Add new axes to the plot</source>
      <translation>Nieuwe assen toevoegen aan plot</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="251"/>
      <source>Remove selected axes</source>
      <translation>Verwijder geselecteerde assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Activeer om transformaties op alle assen toe te passen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="263"/>
      <source>Left bound of axes</source>
      <translation>Linker limiet assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="269"/>
      <source>Right bound of axes</source>
      <translation>Rechter limiet assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="275"/>
      <source>Bottom bound of axes</source>
      <translation>Ondergrens van assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="281"/>
      <source>Top bound of axes</source>
      <translation>Bovengrens van assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Outward offset of X axis</source>
      <translation>Buitenverschuiving van de X-as</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="293"/>
      <source>Outward offset of Y axis</source>
      <translation>Buitenverschuiving van de Y-as</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="299"/>
      <source>X axis scale autoselection</source>
      <translation>Automatische selectie van de X-as schaal</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="305"/>
      <source>Y axis scale autoselection</source>
      <translation>Automatische selectie van de Y-as schaal</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib kon niet worden gevonden, en dus kan de Plot module niet worden geladen</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib kon niet worden gevonden, en dus wordt de Plot module uitgeschakeld</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Plot document moet worden opgeslaan om deze op te slaan</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="365"/>
      <source>Axes 0 can not be deleted</source>
      <translation>0-assen kunnen niet worden verwijderd</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Het raster moet bovenop een 'plot' document geactiveerd worden</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="126"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>De legende moet bovenop een 'plot' document geactiveerd worden</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Benamingen instellen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Active axes</source>
      <translation>Actieve assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="143"/>
      <source>Title</source>
      <translation>Hoofding</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="148"/>
      <source>X label</source>
      <translation>X-benaming</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="153"/>
      <source>Y label</source>
      <translation>Y-benaming</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Index van de actieve assen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Titel (gekoppeld aan actieve assen)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Title font size</source>
      <translation>Lettertype groote van titel</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>X axis title</source>
      <translation>Titel X as</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="181"/>
      <source>X axis title font size</source>
      <translation>Lettergrootte titel X as</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>Y axis title</source>
      <translation>Titel Y as</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="193"/>
      <source>Y axis title font size</source>
      <translation>Lettergrootte voor titel van Y-as</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Posities en groottes instellen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="126"/>
      <source>Position</source>
      <translation>Positie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Size</source>
      <translation>Grootte</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>List of modificable items</source>
      <translation>Lijst met aanpasbare items</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>X-positie van het voorwerp</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>Y item position</source>
      <translation>Y-positie van het voorwerp</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="156"/>
      <source>Item size</source>
      <translation>Afmeting van voorwerp</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="128"/>
      <source>Save figure</source>
      <translation>Figuur opslaan</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Inches</source>
      <translation>Inches</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>Dots per Inch</source>
      <translation>Punten per duim</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="145"/>
      <source>Output image file path</source>
      <translation>Bestandslocatie voor resulterend beeld</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="151"/>
      <source>Show a file selection dialog</source>
      <translation>Toon bestand selectie dialoog</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>X-afmeting van afbeelding</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Y image size</source>
      <translation>Y-afmeting van afbeelding</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Stippen per punt, dewelke de uiteindelijke beeld resolutie definiëren</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>No label</source>
      <translation>Geen benaming</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="160"/>
      <source>Remove serie</source>
      <translation>Verwijder serie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="196"/>
      <source>Line style</source>
      <translation>Lijnstijl</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Marker</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Configureer series</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>List of available series</source>
      <translation>Lijst van beschikbare series</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Line title</source>
      <translation>Lijn titel</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Marker style</source>
      <translation>Marker stijl</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>Line width</source>
      <translation>Lijndikte</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="214"/>
      <source>Marker size</source>
      <translation>Marker grootte</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Line and marker color</source>
      <translation>Kleur van de lijn en marker</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="226"/>
      <source>Removes this serie</source>
      <translation>Verwijder deze serie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="190"/>
      <source>If checked serie will not be considered for legend</source>
      <translation>Indien aangevinkt wordt deze serie niet meegenomen in de legende</translation>
    </message>
  </context>
</TS>

==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Plot/resources/translations/Plot_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="../../InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Plotbewerkingsgereedschappen</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="../../PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Configureer assen</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>De parameters voor de assen instellen</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="../../PlotGui.py" line="109"/>
      <source>Show/Hide grid</source>
      <translation>Raster weergeven/verbergen</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="112"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Weergeven/verbergen raster geselecteerde plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="../../PlotGui.py" line="152"/>
      <source>Set labels</source>
      <translation>Benamingen instellen</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="155"/>
      <source>Set title and axes labels</source>
      <translation>Hoofding en asbenamingen instellen</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="../../PlotGui.py" line="135"/>
      <source>Show/Hide legend</source>
      <translation>Legenda weergeven/verbergen</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="138"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Weergeven/verbergen legende geselecteerde plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="../../PlotGui.py" line="169"/>
      <source>Set positions and sizes</source>
      <translation>Posities en groottes instellen</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="172"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Plaatsing en grootte van benamingen en legende instellen</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="../../PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Plot opslaan</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>De plot als een imagebestand opslaan</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="../../PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Configureer series</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Tekenstijl en benaming van series bepalen</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Configureer assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="179"/>
      <source>Active axes</source>
      <translation>Actieve assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="211"/>
      <source>Apply to all axes</source>
      <translation>Toepassen op alle assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="215"/>
      <source>Dimensions</source>
      <translation>Dimensies</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="219"/>
      <source>X axis position</source>
      <translation>Positie X-as</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="223"/>
      <source>Y axis position</source>
      <translation>Positie Y-as</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="199"/>
      <source>Scales</source>
      <translation>Schalen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="203"/>
      <source>X auto</source>
      <translation>X auto</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="207"/>
      <source>Y auto</source>
      <translation>Y auto</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="227"/>
      <source>Index of the active axes</source>
      <translation>Index van de actieve assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="231"/>
      <source>Add new axes to the plot</source>
      <translation>Nieuwe assen toevoegen aan plot</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="236"/>
      <source>Remove selected axes</source>
      <translation>Verwijder geselecteerde assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="241"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Activeer om transformaties op alle assen toe te passen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="246"/>
      <source>Left bound of axes</source>
      <translation>Linker limiet assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="251"/>
      <source>Right bound of axes</source>
      <translation>Rechter limiet assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="256"/>
      <source>Bottom bound of axes</source>
      <translation>Ondergrens van assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="261"/>
      <source>Top bound of axes</source>
      <translation>Bovengrens van assen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="266"/>
      <source>Outward offset of X axis</source>
      <translation>Buitenverschuiving van de X-as</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="271"/>
      <source>Outward offset of Y axis</source>
      <translation>Buitenverschuiving van de Y-as</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="276"/>
      <source>X axis scale autoselection</source>
      <translation>Automatische selectie van de X-as schaal</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="281"/>
      <source>Y axis scale autoselection</source>
      <translation>Automatische selectie van de Y-as schaal</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="../../Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib kon niet worden gevonden, en dus kan de Plot module niet worden geladen</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib kon niet worden gevonden, en dus wordt de Plot module uitgeschakeld</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Plot document moet worden opgeslaan om deze op te slaan</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="340"/>
      <source>Axes 0 can not be deleted</source>
      <translation>0-assen kunnen niet worden verwijderd</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Het raster moet bovenop een 'plot' document geactiveerd worden</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="125"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>De legende moet bovenop een 'plot' document geactiveerd worden</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Benamingen instellen</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="137"/>
      <source>Active axes</source>
      <translation>Actieve assen</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="141"/>
      <source>Title</source>
      <translation>Hoofding</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="145"/>
      <source>X label</source>
      <translation>X-benaming</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="149"/>
      <source>Y label</source>
      <translation>Y-benaming</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="153"/>
      <source>Index of the active axes</source>
      <translation>Index van de actieve assen</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="157"/>
      <source>Title (associated to active axes)</source>
      <translation>Titel (gekoppeld aan actieve assen)</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="162"/>
      <source>Title font size</source>
      <translation>Lettertype groote van titel</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="167"/>
      <source>X axis title</source>
      <translation>Titel X as</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="172"/>
      <source>X axis title font size</source>
      <translation>Lettergrootte titel X as</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="177"/>
      <source>Y axis title</source>
      <translation>Titel Y as</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="182"/>
      <source>Y axis title font size</source>
      <translation>Lettergrootte voor titel van Y-as</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Posities en groottes instellen</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="125"/>
      <source>Position</source>
      <translation>Positie</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="130"/>
      <source>Size</source>
      <translation>Grootte</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="140"/>
      <source>X item position</source>
      <translation>X-positie van het voorwerp</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="145"/>
      <source>Y item position</source>
      <translation>Y-positie van het voorwerp</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="150"/>
      <source>Item size</source>
      <translation>Afmeting van voorwerp</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="135"/>
      <source>List of modifiable items</source>
      <translation>Lijst van aanpasbare items</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="127"/>
      <source>Save figure</source>
      <translation>Figuur opslaan</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="131"/>
      <source>Inches</source>
      <translation>Inches</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="136"/>
      <source>Dots per Inch</source>
      <translation>Punten per duim</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="141"/>
      <source>Output image file path</source>
      <translation>Bestandslocatie voor resulterend beeld</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="146"/>
      <source>Show a file selection dialog</source>
      <translation>Toon bestand selectie dialoog</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="151"/>
      <source>X image size</source>
      <translation>X-afmeting van afbeelding</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="156"/>
      <source>Y image size</source>
      <translation>Y-afmeting van afbeelding</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="161"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Stippen per punt, dewelke de uiteindelijke beeld resolutie definiëren</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="153"/>
      <source>No label</source>
      <translation>Geen benaming</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="188"/>
      <source>Line style</source>
      <translation>Lijnstijl</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="168"/>
      <source>Marker</source>
      <translation>Marker</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Configureer series</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="173"/>
      <source>List of available series</source>
      <translation>Lijst van beschikbare series</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="178"/>
      <source>Line title</source>
      <translation>Lijn titel</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="193"/>
      <source>Marker style</source>
      <translation>Marker stijl</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="198"/>
      <source>Line width</source>
      <translation>Lijndikte</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="203"/>
      <source>Marker size</source>
      <translation>Marker grootte</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="208"/>
      <source>Line and marker color</source>
      <translation>Kleur van de lijn en marker</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="158"/>
      <source>Remove series</source>
      <translation>Verwijder serie</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="183"/>
      <source>If checked, series will not be considered for legend</source>
      <translation>Indien aangevinkt, wordt deze serie niet beschouwd als legende</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="213"/>
      <source>Removes this series</source>
      <translation>Verwijder deze serie</translation>
    </message>
  </context>
</TS>
